@@ -296,6 +296,7 @@ var Frontend = (new function($)
 		RestoreSettingsDialog.init();
 		LimitDialog.init();
 		SystemInfo.init();
+		Statistics.init();
 
 		DownloadsEditDialog.init();
 		DownloadsMultiDialog.init();
@@ -396,6 +397,8 @@ var Frontend = (new function($)
 			link = 'MessagesTabLink';
 		else if (location.indexOf('#settings') > -1)
 			link = 'ConfigTabLink';
+		else if (location.indexOf('#statistics') > -1)
+			link = 'StatisticsTabLink';
 		if (link)
 		{
 			$('#DownloadsTab').removeClass('fade');
@@ -482,7 +485,7 @@ var Frontend = (new function($)
 			return;
 		}
 
-		var filterBox = $('#DownloadsTable_filter, #HistoryTable_filter, #MessagesTable_filter, #ConfigTable_filter');
+		var filterBox = $('#DownloadsTable_filter, #HistoryTable_filter, #MessagesTable_filter, #ConfigTable_filter', '#StatisticsTable_filter');
 		if (filterBox.is(':focus') && (key === 'Escape' || key === 'Enter'))
 		{
 			filterBox.blur();
@@ -497,6 +500,7 @@ var Frontend = (new function($)
 				case 'History': if (History.processShortcut(key)) return false;
 				case 'Messages': if (Messages.processShortcut(key)) return false;
 				case 'Config': if (Config.processShortcut(key)) return false;
+				case 'Statistics': if (Config.processShortcut(key)) return false;
 			}
 			switch (key)
 			{
@@ -504,6 +508,7 @@ var Frontend = (new function($)
 				case 'Shift+H': $('#HistoryTabLink').click(); return false;
 				case 'Shift+M': $('#MessagesTabLink').click(); return false;
 				case 'Shift+S': $('#ConfigTabLink').click(); return false;
+				case 'Shift+I': $('#StatisticsTabLink').click(); return false;
 				case 'Shift+L': $('#StatusSpeed').click(); return false;
 				case 'Shift+A': $('#StatusTime').click(); return false;
 				case 'Shift+R': $('#RefreshButton').click(); return false;
@@ -657,9 +662,6 @@ var Frontend = (new function($)
 		if (UISettings.miniTheme)
 		{
 			var w = $('#NavbarContainer').width() - $('#RefreshBlockPhone').outerWidth() - ScrollDelta;
-			var $btns = $('#Navbar ul.nav > li');
-			var buttonWidth = w / $btns.length;
-			$btns.css('min-width', buttonWidth + 'px');
 			$('#NavLinks').css('margin-left', 0);
 			$('body').toggleClass('navfixed', false);
 		}
@@ -869,6 +871,7 @@ var Refresher = (new function($)
 
 		loadQueue = 4;
 		Status.update();
+		Statistics.update();
 		Downloads.update();
 		Messages.update();
 		History.update();
